@@ -24,14 +24,16 @@ use theme::{ColorTheme, BORDER_SIZE, HEADER_SIZE};
 
 mod buttons;
 use buttons::{ButtonKind, Buttons};
-use title::TitleText;
 
 use crate::theme::ColorMap;
 
 mod parts;
 mod pointer;
 mod surface;
+#[cfg(feature = "title")]
 mod title;
+#[cfg(feature = "title")]
+use title::TitleText;
 
 /*
  * Utilities
@@ -160,6 +162,7 @@ pub struct AdwaitaFrame {
     buttons: Rc<RefCell<Buttons>>,
     colors: ColorTheme,
     title: Option<String>,
+    #[cfg(feature = "title")]
     title_text: TitleText,
 }
 
@@ -210,6 +213,7 @@ impl Frame for AdwaitaFrame {
             surface_version: compositor.as_ref().version(),
             buttons: Default::default(),
             title: None,
+            #[cfg(feature = "title")]
             title_text: TitleText::new(colors.active.font_color).unwrap(),
             colors,
         })
@@ -340,6 +344,7 @@ impl Frame for AdwaitaFrame {
                     &self.colors.inactive
                 };
 
+                #[cfg(feature = "title")]
                 self.title_text.update_color(colors.font_color);
 
                 let border_paint = colors.border_paint();
@@ -355,11 +360,15 @@ impl Frame for AdwaitaFrame {
                         PixmapMut::from_bytes(canvas, header_width, header_height).unwrap();
                     pixmap.fill(Color::TRANSPARENT);
 
+                    #[cfg(feature = "title")]
                     self.title_text.update_scale(header_scale);
 
                     draw_headerbar(
                         &mut pixmap,
+                        #[cfg(feature = "title")]
                         self.title_text.pixmap(),
+                        #[cfg(not(feature = "title"))]
+                        None,
                         header_scale as f32,
                         inner.resizable,
                         self.active,
@@ -574,6 +583,7 @@ impl Frame for AdwaitaFrame {
     }
 
     fn set_title(&mut self, title: String) {
+        #[cfg(feature = "title")]
         self.title_text.update_title(&title);
         self.title = Some(title);
     }
